[Cmake-commits] CMake branch, next, updated. v2.8.6-2028-ga95cfca

Stephen Kelly steveire at gmail.com
Sat Nov 26 09:32:33 EST 2011


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
       via  a95cfcaa54507b7ab2c223a951d18ed3fc92ced1 (commit)
       via  a8286235a31437505a53f5874e8bf98524b6dca3 (commit)
       via  b8c8cab2428b10d5a1cb3af4ae72bc3c3f091f4d (commit)
      from  9e7fde55127cb2bd1e9ab52d97b43db09ad89a16 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a95cfcaa54507b7ab2c223a951d18ed3fc92ced1
commit a95cfcaa54507b7ab2c223a951d18ed3fc92ced1
Merge: 9e7fde5 a828623
Author:     Stephen Kelly <steveire at gmail.com>
AuthorDate: Sat Nov 26 09:32:31 2011 -0500
Commit:     CMake Topic Stage <kwrobot at kitware.com>
CommitDate: Sat Nov 26 09:32:31 2011 -0500

    Merge topic 'automoc_qt5' into next
    
    a828623 moc is now part of the Qt5Core module
    b8c8cab Merge remote-tracking branch 'origin/master' into automoc_qt5


http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a8286235a31437505a53f5874e8bf98524b6dca3
commit a8286235a31437505a53f5874e8bf98524b6dca3
Author:     Stephen Kelly <steveire at gmail.com>
AuthorDate: Sat Nov 26 15:15:33 2011 +0100
Commit:     Stephen Kelly <steveire at gmail.com>
CommitDate: Sat Nov 26 15:15:33 2011 +0100

    moc is now part of the Qt5Core module
    
    There is no separate SrcTools module anymore.

diff --git a/Modules/AutomocInfo.cmake.in b/Modules/AutomocInfo.cmake.in
index 8542ff6..2c7c724 100644
--- a/Modules/AutomocInfo.cmake.in
+++ b/Modules/AutomocInfo.cmake.in
@@ -11,5 +11,5 @@ set(AM_QT_MOC_EXECUTABLE "@QT_MOC_EXECUTABLE@")
 set(AM_CMAKE_CURRENT_SOURCE_DIR "@CMAKE_CURRENT_SOURCE_DIR@/")
 set(AM_CMAKE_CURRENT_BINARY_DIR "@CMAKE_CURRENT_BINARY_DIR@/")
 set(AM_QT_VERSION_MAJOR "@QT_VERSION_MAJOR@" )
-set(AM_Qt5SrcTools_VERSION_MAJOR "@Qt5SrcTools_VERSION_MAJOR@" )
+set(AM_Qt5Core_VERSION_MAJOR "@Qt5Core_VERSION_MAJOR@" )
 set(AM_TARGET_NAME "@_moc_target_name@")
diff --git a/Source/cmQtAutomoc.cxx b/Source/cmQtAutomoc.cxx
index 7a80f28..d07f84b 100644
--- a/Source/cmQtAutomoc.cxx
+++ b/Source/cmQtAutomoc.cxx
@@ -49,11 +49,11 @@ void cmQtAutomoc::SetupAutomocTarget(cmTarget* target)
 {
   cmMakefile* makefile = target->GetMakefile();
   const char* targetName = target->GetName();
   // don't do anything if there is no Qt4 or Qt5SrcTools (which contains moc):
   std::string qtMajorVersion = makefile->GetSafeDefinition("QT_VERSION_MAJOR");
   if (qtMajorVersion == "")
     {
-    qtMajorVersion = makefile->GetSafeDefinition("Qt5SrcTools_VERSION_MAJOR");
+    qtMajorVersion = makefile->GetSafeDefinition("Qt5Core_VERSION_MAJOR");
     }
   if (qtMajorVersion != "4" && qtMajorVersion != "5")
     {
@@ -229,7 +229,7 @@ bool cmQtAutomoc::ReadAutomocInfoFile(cmMakefile* makefile,
   if (this->QtMajorVersion == "")
     {
     this->QtMajorVersion = makefile->GetSafeDefinition(
-                                     "AM_Qt5SrcTools_VERSION_MAJOR");
+                                     "AM_Qt5Core_VERSION_MAJOR");
     }
   this->Sources = makefile->GetSafeDefinition("AM_SOURCES");
   this->Headers = makefile->GetSafeDefinition("AM_HEADERS");

http://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b8c8cab2428b10d5a1cb3af4ae72bc3c3f091f4d
commit b8c8cab2428b10d5a1cb3af4ae72bc3c3f091f4d
Merge: bafe5cc 5675ec5
Author:     Stephen Kelly <steveire at gmail.com>
AuthorDate: Thu Nov 10 15:46:13 2011 +0100
Commit:     Stephen Kelly <steveire at gmail.com>
CommitDate: Thu Nov 10 15:46:13 2011 +0100

    Merge remote-tracking branch 'origin/master' into automoc_qt5


-----------------------------------------------------------------------

Summary of changes:
 Modules/AutomocInfo.cmake.in |    2 +-
@@ -49,11 +49,11 @@ void cmQtAutomoc::SetupAutomocTarget(cmTarget* target)
   cmMakefile* makefile = target->GetMakefile();
   const char* targetName = target->GetName();
-  // don't do anything if there is no Qt4 or Qt5SrcTools (which contains moc):
+  // don't do anything if there is no Qt4 or Qt5Core (which contains moc):
   std::string qtMajorVersion = makefile->GetSafeDefinition("QT_VERSION_MAJOR");
   if (qtMajorVersion == "")
 Source/cmQtAutomoc.cxx       |    6 +++---
 2 files changed, 4 insertions(+), 4 deletions(-)


hooks/post-receive
-- 
CMake


More information about the Cmake-commits mailing list